<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg CSS Frontend
 * @copyright   Copyright (c) 2023, WeCodeArt Framework
 * @since		5.5.5
 * @version		6.0.0
 */

namespace WeCodeArt\Gutenberg\Modules\Styles\Blocks;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Gutenberg\Modules\Styles\Processor;
use function WeCodeArt\Functions\get_prop;

/**
 * Block CSS Processor
 */
class Gallery extends Processor {
	/**
	 * Parses an output and creates the styles array for it.
	 *
	 * @return 	void
	 */
	protected function process_extra(): void {
		$declarations = [];

		// Gap
		if( $gap = get_prop( $this->attrs, [ 'style', 'spacing', 'blockGap' ] ) ) {
			if( count( $gap ) === 2 && count( array_unique( $gap ) ) === 1 ) {
				$gap = current( $gap );
			}

			if ( is_array( $gap ) ) {
				$gap_y	= get_prop( $gap, [ 'top' ] );
				$gap_x	= get_prop( $gap, [ 'left' ] );

				// Is WP way of saved color
				if( mb_strpos( $gap_x, 'var:preset|spacing' ) !== false ) {
					$gap_x = explode( '|', $gap_x );
					$gap_x = sprintf( 'var(--wp--preset--spacing--%s)', end( $gap_x ) );
				}

				// Is WP way of saved color
				if( mb_strpos( $gap_y, 'var:preset|spacing' ) !== false ) {
					$gap_y = explode( '|', $gap_y );
					$gap_y = sprintf( 'var(--wp--preset--spacing--%s)', end( $gap_y ) );
				}

				$gap = $gap_y . ' ' . $gap_x;
			} else {
				// Is WP way of saved color
				if( mb_strpos( $gap, 'var:preset|spacing' ) !== false ) {
					$gap = explode( '|', $gap );
					$gap = sprintf( 'var(--wp--preset--spacing--%s)', end( $gap ) );
				}
			}

			$declarations['--wp--style--block-gap'] = $gap;
		}

		// Columns
		if( $columns = get_prop( $this->attrs, 'columns', 3 ) ) {
			$declarations['--wp--columns'] = $columns;
		}

		if( ! empty( $declarations ) ) {
			$this->add_declarations( $declarations );
		}
	}
}