<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Gutenberg CSS Frontend
 * @copyright   Copyright (c) 2023, WeCodeArt Framework
 * @since		5.4.8
 * @version		6.0.0
 */

namespace WeCodeArt\Gutenberg\Modules\Styles\Blocks;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Modules\Styles\Processor;
use function WeCodeArt\Functions\get_prop;

/**
 * Block CSS Processor
 */
class Search extends Processor {
	/**
	 * Parses an output and creates the styles array for it.
	 *
	 * @return 	void
	 */
	protected function process_extra(): void {
		// Width
		if( ! in_array( get_prop( $this->attrs, 'width' ), [ 25, 50, 75, 100 ] ) ) {
			$this->add_declarations( [
				'width' => get_prop( $this->attrs, 'width' ) . get_prop( $this->attrs, 'widthUnit' )
			], $this->get_selector( ' .wp-block-search__fields' ) );
		}

		// Update Selector
		$new_selector = join( ', ', [
			$this->get_selector( ' .wp-block-search__input' ),
			$this->get_selector( ' .wp-element-button' )
		] );

		add_filter( 'wecodeart/filter/gutenberg/styles/selector', function( $selector, $name ) use ( $new_selector ) {
			if( 'core/search' === $name ) {
				$selector = $new_selector;
			}
			
			remove_filter( current_filter(), __FUNCTION__ );

			return $selector;
		}, 10, 2 );
	}
}