<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework 
 * @subpackage 	Markup\Inputs
 * @copyright   Copyright (c) 2023, WeCodeArt Framework
 * @since		6.0.0
 * @version		6.0.0
 */

namespace WeCodeArt\Support\Markup\Inputs;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Support\Markup\Inputs\Basic;
use function WeCodeArt\Functions\get_prop;

/**
 * Standard Inputs Markup
 */
class Color extends Basic {
    /**
     * Input's Style Deps.
     *
     * @since   6.0.0
     * @var     array
     */
    static $style_deps = [ 'basic' ];

    /**
	 * Constructor 
	 */
	public function __construct( string $type = 'color', array $args = [] ) {
        parent::__construct( $type, $args );
    }

    /**
     * Get input's class.
     * 
     * @since   6.0.0
     * @version 6.0.0
     *
     * @param 	string
     */
    public function input_class(): string {
        return 'form-control form-control-color';
    }

    /**
	 * Input styles.
	 *
	 * @return 	string
	 */
	public static function styles(): string {
		return '
			::-webkit-color-swatch-wrapper {
				padding: 0;
			}
            .form-control-color {
                width: 3rem;
                height: calc(1.5em + var(--wp--input--padding-x) + 2px);
                padding: var(--wp--input--padding-y);
            }
            .form-control-color:not(:disabled):not([readonly]) {
                cursor: pointer;
            }
            .form-control-color::-moz-color-swatch {
                border: 0 !important;
                border-radius: var(--wp--input--border-radius);
            }
            .form-control-color::-webkit-color-swatch {
                border-radius: var(--wp--input--border-radius);
            }
            .form-control-color.form-control-sm {
                height: calc(1.5em + 0.5rem + 2px);
            }
            .form-control-color.form-control-lg {
                height: calc(1.5em + 1rem + 2px);
            }

            .was-validated .form-control-color:invalid,
            .form-control-color.is-invalid {
                width: calc(3rem + calc(1.5em + var(--wp--input--padding-x)));
            }
        ';
	}
}