<?php
/**
 * WeCodeArt Framework
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package		WeCodeArt Framework
 * @subpackage  Yoast\Blocks
 * @copyright   Copyright (c) 2023, WeCodeArt Framework
 * @since		6.0.0
 * @version		6.0.0
 */

namespace WeCodeArt\Support\Plugins\WPSeo\Blocks;

defined( 'ABSPATH' ) || exit();

use WeCodeArt\Singleton;
use WeCodeArt\Gutenberg\Blocks\Dynamic;

use function add_filter;
use function WeCodeArt\Functions\get_dom_element;
use function WeCodeArt\Functions\change_tag_name;
use function WeCodeArt\Functions\get_elements_by_class_name;

/**
 * Gutenberg Yoast FAQ block.
 */
class Faq extends Dynamic {

	use Singleton;

	/**
	 * Block namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'yoast';

	/**
	 * Block name.
	 *
	 * @var string
	 */
	protected $block_name = 'faq-block';

	/**
	 * Block args.
	 *
	 * @return 	array
	 */
	public function block_type_args(): array {
		return [
			'render_callback' => [ $this, 'render' ]
		];
	}

    /**
	 * Filter FAQ
	 * 
	 * @param 	string 	$attributes
	 * @param 	array 	$content
	 * 
	 * @return 	string
	 */
	public function render( array $attributes = [], string $content = '' ): string {
		$dom		= $this->dom( $content );
		$sections	= get_elements_by_class_name( $dom, 'schema-faq-section' );

		if( count( $sections ) ) {
			foreach( $sections as $section ) {
				$section = change_tag_name( $section, 'details' );
				$summary = change_tag_name( get_dom_element( 'strong', $section, 0 ), 'summary' );
			}
		}

		return $dom->saveHtml();
	}

	/**
	 * Block styles
	 *
	 * @return 	string 	The block styles.
	 */
	public function styles(): string {
		return '
			.wp-block-yoast-faq-block {
				--wp--faq--padding-y: 1rem;
				--wp--faq--padding-x: 2rem;
				--wp--faq--padding: var(--wp--faq--padding-y) var(--wp--faq--padding-x);
				--wp--faq--chevron-size: .4rem;
				--wp--faq--chevron-color: currentColor;
				--wp--faq--chevron-transition: .25s transform ease;
				--wp--faq--border: 1px solid var(--wp--gray-300);
				border: var(--wp--faq--border);
			}
			.wp-block-yoast-faq-block details + details {
				border-top: var(--wp--faq--border);
			}
			.wp-block-yoast-faq-block summary {
				position: relative;
				display: block;
				padding: var(--wp--faq--padding);
				font-size: var(--wp--preset--font-size--normal);
				font-weight: 700;
				cursor: pointer;
			}
			.wp-block-yoast-faq-block summary::before {
				content: "";
				position: absolute;
				top: calc(50% - var(--wp--faq--chevron-size));
				left: 1rem;
				border-width: var(--wp--faq--chevron-size);
				border-style: solid;
				border-color: transparent transparent transparent var(--wp--faq--chevron-color);
				transform: rotate(0);
				transform-origin: .125em 50%;
				transition: var(--wp--faq--chevron-transition);
			}
			.wp-block-yoast-faq-block summary:hover,
			.wp-block-yoast-faq-block summary:focus,
			.wp-block-yoast-faq-block details[open] summary {
				background-color: var(--wp--gray-100);
			}
			.wp-block-yoast-faq-block details[open] summary {
				border-bottom: var(--wp--faq--border);
			}
			.wp-block-yoast-faq-block details[open] > summary::before {
				transform: rotate(90deg);
			}
			.wp-block-yoast-faq-block details summary::-webkit-details-marker {
				display: none;
			}
			.wp-block-yoast-faq-block .schema-faq-answer {
				padding: var(--wp--faq--padding);
				margin: 0;
			}
		';
	}
}
